@@ -1,7 +1,7 @@
 package App::RemovePdfPassword;
 
-our $DATE = '2017-02-13'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-02-23'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -91,6 +91,7 @@ sub remove_pdf_password {
                 "qpdf", "--password=$p", "--decrypt", $f, $tempf);
             my $err = $?;# ? Proc::ChildError::explain_child_error() : '';
             if ($err && $stderr =~ /: invalid password$/) {
+                unlink $tempf; # just to make sure
                 next PASSWORD;
             } elsif ($err) {
                 $stderr =~ s/\R//g;
@@ -98,6 +99,10 @@ sub remove_pdf_password {
                 next FILE;
             }
         }
+        unless (-f $tempf) {
+            $envres->add_result(412, "No passwords can be successfully used on $f", {item_id=>$f});
+            next FILE;
+        }
 
       BACKUP:
         {
@@ -132,7 +137,7 @@ App::RemovePdfPassword - Remove password from PDF files
 
 =head1 VERSION
 
-This document describes version 0.002 of App::RemovePdfPassword (from Perl distribution App-RemovePdfPassword), released on 2017-02-13.
+This document describes version 0.003 of App::RemovePdfPassword (from Perl distribution App-RemovePdfPassword), released on 2017-02-23.
 
 =head1 SYNOPSIS
 
